@@ -2,10 +2,7 @@ use 5.006;
 use strict;
 use warnings;
 package CPAN::Meta;
-BEGIN {
-  $CPAN::Meta::VERSION = '2.110910';
-}
-# ABSTRACT: the distribution metadata for a CPAN dist
+our $VERSION = '2.112580'; # VERSION
 
 
 use Carp qw(carp croak);
@@ -15,13 +12,7 @@ use CPAN::Meta::Converter;
 use CPAN::Meta::Validator;
 use Parse::CPAN::Meta 1.4400 ();
 
-sub _dclone {
-  my $ref = shift;
-  my $backend = Parse::CPAN::Meta->json_backend();
-  return $backend->new->decode(
-    $backend->new->convert_blessed->encode($ref)
-  );
-}
+BEGIN { *_dclone = \&CPAN::Meta::Converter::_dclone }
 
 
 BEGIN {
@@ -223,7 +214,6 @@ sub save {
 }
 
 
-# XXX Do we need this if we always upconvert? -- dagolden, 2010-04-14
 sub meta_spec_version {
   my ($self) = @_;
   return $self->meta_spec->{version};
@@ -313,7 +303,7 @@ sub as_string {
   my $version = $options->{version} || '2';
 
   my $struct;
-  if ( $self->version ne $version ) {
+  if ( $self->meta_spec_version ne $version ) {
     my $cmc = CPAN::Meta::Converter->new( $self->as_struct );
     $struct = $cmc->convert( version => $version );
   }
@@ -344,6 +334,8 @@ sub TO_JSON {
 
 1;
 
+# ABSTRACT: the distribution metadata for a CPAN dist
+
 
 
 =pod
@@ -354,7 +346,7 @@ CPAN::Meta - the distribution metadata for a CPAN dist
 
 =head1 VERSION
 
-version 2.110910
+version 2.112580
 
 =head1 SYNOPSIS
 
@@ -649,6 +641,10 @@ particular keys may be retrieved with the C<custom> method.
 
 If a custom key refers to a data structure, a deep clone is returned.
 
+=for Pod::Coverage TO_JSON abstract author authors custom custom_keys description dynamic_config
+generated_by keywords license licenses meta_spec name no_index
+optional_features prereqs provides release_status resources version
+
 =head1 BUGS
 
 Please report any bugs or feature using the CPAN Request Tracker.
@@ -672,6 +668,25 @@ L<CPAN::Meta::Validator>
 
 =back
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-cpan-meta at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=CPAN-Meta>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<http://github.com/dagolden/cpan-meta>
+
+  git clone git://github.com/dagolden/cpan-meta.git
+
 =head1 AUTHORS
 
 =over 4
