@@ -2,10 +2,7 @@ use 5.006;
 use strict;
 use warnings;
 package CPAN::Meta::Converter;
-BEGIN {
-  $CPAN::Meta::Converter::VERSION = '2.110910';
-}
-# ABSTRACT: Convert CPAN distribution metadata structures
+our $VERSION = '2.112580'; # VERSION
 
 
 use CPAN::Meta::Validator;
@@ -14,9 +11,17 @@ use Parse::CPAN::Meta 1.4400 ();
 
 sub _dclone {
   my $ref = shift;
+
+  # if an object is in the data structure and doesn't specify how to
+  # turn itself into JSON, we just stringify the object.  That does the
+  # right thing for typical things that might be there, like version objects,
+  # Path::Class objects, etc.
+  no warnings 'once';
+  local *UNIVERSAL::TO_JSON = sub { return "$_[0]" };
+
   my $backend = Parse::CPAN::Meta->json_backend();
-  return $backend->new->decode(
-    $backend->new->convert_blessed->encode($ref)
+  return $backend->new->utf8->decode(
+    $backend->new->utf8->allow_blessed->convert_blessed->encode($ref)
   );
 }
 
@@ -1243,6 +1248,8 @@ sub convert {
 
 1;
 
+# ABSTRACT: Convert CPAN distribution metadata structures
+
 
 
 =pod
@@ -1253,7 +1260,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.110910
+version 2.112580
 
 =head1 SYNOPSIS
 
